@@ -7,6 +7,7 @@ if sys.version < '3':
     from urllib2 import URLError
 else:
     from urllib.error import URLError
+from django.views.decorators.csrf import csrf_exempt
 from django.conf import settings
 import flat.comm
 import flat.users
@@ -32,6 +33,7 @@ def view(request, namespace, docid):
         return fatalerror(request,"Permission denied")
 
 
+@csrf_exempt
 def pub_view(request, docid, configuration):
     """The initial view, does not provide the document content yet"""
     if 'autodeclare' in settings.CONFIGURATIONS[configuration]:
@@ -41,7 +43,7 @@ def pub_view(request, docid, configuration):
             except Exception as e:
                 return fatalerror(request,e)
 
-    return initdoc(request, 'pub',docid, 'editor', 'editor.html')
+    return initdoc(request, 'pub',docid, 'editor', 'editor.html', configuration=configuration)
 
 @login_required
 def history(request,namespace, docid):
