@@ -1090,7 +1090,7 @@ function viewer_onupdate() {
         if (slicesize[perspective]) {
             var page = $('#pagemenu').val();
             perspitems.each(function(idx){
-                perspitems[idx].innerHTML = "<span class=\"seqnr\">" + (((page -1) * slicesize[perspective]) + (idx +1))  + "</span>" + perspitems[idx].innerHTML;
+                $(perspitems[idx]).prepend("<span class=\"seqnr\">" + (((page -1) * slicesize[perspective]) + (idx +1))  + "</span>");
             });
         }
     }
@@ -1181,6 +1181,11 @@ function viewer_contentloaded(data) {
     if (annotationfocus) {
         setannotationfocus(annotationfocus.type, annotationfocus.set);
     }
+    if (configuration.searches) {
+        for (var i = 0; i < configuration.searches.length; i++) {
+            if (configuration.searches[i].auto) presetsearch(i);
+        }
+    }
 }
 
 
@@ -1195,6 +1200,10 @@ function viewer_onpagechange() {
     //resubmit any searches if there is a search and highlight mode is selected
     if ((searchsubmitted) && ($('#searchqueryinput').val() !== "") && ($('#searchhighlight').is(':checked'))) {
         $('#searchsubmit').click();
+    } else if (configuration.searches) {
+        for (var i = 0; i < configuration.searches.length; i++) {
+            if (configuration.searches[i].auto) presetsearch(i);
+        }
     }
 }
 
