@@ -1,8 +1,10 @@
 from __future__ import print_function, unicode_literals, division, absolute_import
+import sys
 import os
 import json
 import datetime
-import sys
+import logging
+
 from collections import defaultdict
 
 from django.shortcuts import render, redirect
@@ -24,6 +26,9 @@ if sys.version < '3':
 else:
     from urllib.error import URLError, HTTPError
 
+# Get an instance of a logger
+logger = logging.getLogger(__name__)
+
 def getcontext(request,namespace,docid, doc, mode, configuration = None):
     if configuration is None:
         if 'configuration' not in request.session:
@@ -43,6 +48,7 @@ def getcontext(request,namespace,docid, doc, mode, configuration = None):
             'perspectives_json': json.dumps(settings.CONFIGURATIONS[configuration]['perspectives']),
             'docdeclarations': json.dumps(doc['declarations']) if 'declarations' in doc else "{}",
             'setdefinitions': json.dumps(doc['setdefinitions']) if 'setdefinitions' in doc else "{}",
+            'excludeclasses': json.dumps(settings.CONFIGURATIONS[configuration]['excludeclasses']) if 'excludeclasses' in settings.CONFIGURATIONS[configuration] else "{}",
             'metadata': json.dumps(doc['metadata']) if 'metadata' in doc else "{}",
             'toc': json.dumps(doc['toc']) if 'toc' in doc else "[]",
             'slices': json.dumps(doc['slices']) if 'slices' in doc else "{}",
@@ -81,6 +87,7 @@ def getbody(html):
 
 def docserveerror(e, d=None):
     if d is None: d={}
+    raise e
     if isinstance(e, HTTPError):
         body = getbody(e.read())
         d['fatalerror'] =  "<strong>Fatal Error:</strong> The document server returned an error<pre style=\"font-weight: bold\">" + str(e) + "</pre><pre>" + body +"</pre>"
@@ -224,6 +231,7 @@ def query(request,namespace, docid):
     else:
         return HttpResponseForbidden("Permission denied, no read access")
 
+@csrf_exempt
 def pub_query(request,configuration, docid):
     if request.method != 'POST':
         return HttpResponseForbidden("POST method required for pub/" + docid + "/query")
@@ -248,12 +256,12 @@ def login(request):
                     return redirect("/")
             else:
                 # Return a 'disabled account' error message
-                return render(request, 'login.html', {'error': "This account is disabled","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS , 'version': settings.VERSION} )
+                return render(request, 'login.html', {'error': "This account is disabled","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS , 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION} )
         else:
             # Return an 'invalid login' error message.
-            return render(request, 'login.html', {'error': "Invalid username or password","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION} )
+            return render(request, 'login.html', {'error': "Invalid username or password","defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, 'version': settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION} )
     else:
-        return render(request, 'login.html',{"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, "version": settings.VERSION})
+        return render(request, 'login.html',{"defaultconfiguration":settings.DEFAULTCONFIGURATION, "configurations":settings.CONFIGURATIONS, "version": settings.VERSION, "allowregistration": hasattr(settings, 'ALLOWREGISTRATION') and settings.ALLOWREGISTRATION})
 
 
 def logout(request):
@@ -264,6 +272,9 @@ def logout(request):
 
 
 def register(request):
+    if hasattr(settings, 'ALLOWREGISTRATION') and not settings.ALLOWREGISTRATION:
+        return HttpResponseForbidden("Registration disabled")
+
     if request.method == 'POST':
         form = django.contrib.auth.forms.UserCreationForm(request.POST)
         if form.is_valid():
@@ -377,6 +388,7 @@ def download(request, namespace, docid):
     data = flat.comm.query(request, "USE " + namespace + "/" + docid + " GET",False)
     return HttpResponse(data, content_type='text/xml')
 
+@csrf_exempt
 def pub_download(request, docid):
     data = flat.comm.query(request, "USE pub/" + docid + " GET",False)
     return HttpResponse(data, content_type='text/xml')
@@ -505,6 +517,7 @@ def upload_helper(request, namespace, configuration=None, mode=None):
         return fatalerror(request, response['error'],403)
     else:
         docid = response['docid']
+        logger.info("Succesfully uploaded " + docid + "(namespace=" + namespace+")")
         if namespace == "pub":
             return HttpResponseRedirect("/" + mode + "/pub/" + configuration + "/" + docid  )
         else:
@@ -534,6 +547,7 @@ def pub_upload(request):
                 mode = request.POST['mode']
             else:
                 mode = settings.DEFAULTMODE
+            logger.info("Receiving public upload for configuration " + configuration + ", mode " + mode)
             return upload_helper(request, 'pub', configuration, mode)
         else:
             return fatalerror(request, "Public anonymous write permission denied",403)
