@@ -93,6 +93,9 @@ DEFAULTMODE = 'editor'
 # will be selected by default:
 DEFAULTCONFIGURATION = 'full'
 
+# Allow users to register their own accounts?
+ALLOWREGISTRATION = True
+
 # Allow public anonymous uploads without any authentication?
 ALLOWPUBLICUPLOAD = False
 
@@ -239,7 +242,7 @@ CONFIGURATIONS = {
     #Dictionary of metadata keys to lists of possible values, constrains the values in the metadata editor rather than offering a free-fill field. Example:
     #'metadataconstraints': {'language': ['fr','en','es'], 'status':['completed','inprogress']},
 
-    #'searches': [{'query': 'SELECT entity WHERE annotatortype = "manual" FOR w RETURN target', 'label': "Highlight manually annotated entities"}]
+    #'searches': [{'query': 'SELECT entity WHERE annotatortype = "manual" FOR w RETURN target', 'label': "Highlight manually annotated entities", 'changeperspective': false}]
 },
 }
 
@@ -475,10 +478,13 @@ raise Exception("settings.py hasn't been configured yet!!")
 
 # $ export PYTHONPATH=/your/settings/path/
 # $ export DJANGO_SETTINGS_MODULE=settings
-# $ django-admin makemigrations
 # $ django-admin migrate --run-syncdb
 # $ django-admin createsuperuser
 
 # In any case, don't forget to start the document server too:
 
 # $ foliadocserve -d /path/to/document/root -p 8080 --git
+
+# If you use the --git option, make sure your git identity is configured
+#    git config --global user.email "you@example.com"
+#    git config --global user.name "Your Name"
